"""
Hooking into the auth system
"""

# Alliance Auth
from allianceauth import hooks


@hooks.register("discord_cogs_hook")
def register_cogs():
    """
    Registering our discord cogs
    :return:
    :rtype:
    """

    return ["aa_rss_to_discord.discordbot.cogs.rss"]



"""
app config
"""

# Django
from django.apps import AppConfig
from django.utils.text import format_lazy

# AA RSS to Discord
from aa_rss_to_discord import __title_translated__, __version__


class AaRssToDiscordConfig(AppConfig):
    """
    application config
    """

    name = "aa_rss_to_discord"
    label = "aa_rss_to_discord"
    verbose_name = format_lazy(
        "{app_title} v{version}", app_title=__title_translated__, version=__version__
    )



"""
constants
"""

# Third Party
from feedparser import USER_AGENT as feedparser_user_agent

# AA RSS to Discord
from aa_rss_to_discord import __version__

APP_NAME = "aa-rss-to-discord"
APP_NAME_USERAGENT = "AA-RSS-to-Discord"
GITHUB_URL = f"https://github.com/ppfeufer/{APP_NAME}"
USER_AGENT = (
    f"{APP_NAME_USERAGENT}/{__version__} (+{GITHUB_URL}) via {feedparser_user_agent}"
)



# Generated by Django 3.1.8 on 2021-04-30 09:30

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("aadiscordbot", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="RssFeeds",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(default="", max_length=254)),
                ("url", models.CharField(default="", max_length=254)),
                (
                    "discord_channel",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="aadiscordbot.channels",
                    ),
                ),
            ],
            options={
                "verbose_name": "RSS Feed",
                "verbose_name_plural": "RSS Feeds",
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="LastItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "rss_item_time",
                    models.CharField(blank=True, default="", max_length=254),
                ),
                ("rss_item_title", models.CharField(default="", max_length=254)),
                ("rss_item_link", models.CharField(default="", max_length=254)),
                (
                    "rss_item_guid",
                    models.CharField(blank=True, default="", max_length=254),
                ),
                (
                    "rss_feed",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="aa_rss_to_discord.rssfeeds",
                    ),
                ),
            ],
            options={
                "verbose_name": "Last Item",
                "verbose_name_plural": "Last Items",
                "default_permissions": (),
            },
        ),
    ]



# Generated by Django 3.2.3 on 2021-05-25 08:21

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aa_rss_to_discord", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="rssfeeds",
            name="enabled",
            field=models.BooleanField(default=True),
        ),
    ]
